==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DataSourceParametersPostgresqlArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property database The database to which to connect.
 * @property host The host to which to connect.
 * @property port The port to which to connect.
 */
public data class DataSourceParametersPostgresqlArgs(
    public val database: Output<String>,
    public val host: Output<String>,
    public val port: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs =
        com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs.builder()
            .database(database.applyValue({ args0 -> args0 }))
            .host(host.applyValue({ args0 -> args0 }))
            .port(port.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSourceParametersPostgresqlArgs].
 */
@PulumiTagMarker
public class DataSourceParametersPostgresqlArgsBuilder internal constructor() {
    private var database: Output<String>? = null

    private var host: Output<String>? = null

    private var port: Output<Int>? = null

    /**
     * @param value The database to which to connect.
     */
    @JvmName("wcbhuqnomxlcitfh")
    public suspend fun database(`value`: Output<String>) {
        this.database = value
    }

    /**
     * @param value The host to which to connect.
     */
    @JvmName("autvjccygsiligtj")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value The port to which to connect.
     */
    @JvmName("foxnkjacwiujovbn")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value The database to which to connect.
     */
    @JvmName("lghqrcbxfhiibaeg")
    public suspend fun database(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.database = mapped
    }

    /**
     * @param value The host to which to connect.
     */
    @JvmName("uxodygbxoxovusjm")
    public suspend fun host(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value The port to which to connect.
     */
    @JvmName("tmjulaxowwosdyvc")
    public suspend fun port(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.port = mapped
    }

    internal fun build(): DataSourceParametersPostgresqlArgs = DataSourceParametersPostgresqlArgs(
        database = database ?: throw PulumiNullFieldException("database"),
        host = host ?: throw PulumiNullFieldException("host"),
        port = port ?: throw PulumiNullFieldException("port"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DataSourceParametersPostgresqlArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property database The database to which to connect.
 * @property host The host to which to connect.
 * @property port The port to which to connect.
 */
public data class DataSourceParametersPostgresqlArgs(
    public val database: Output<String>,
    public val host: Output<String>,
    public val port: Output<Int>,
) : ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs =
        com.pulumi.aws.quicksight.inputs.DataSourceParametersPostgresqlArgs.builder()
            .database(database.applyValue({ args0 -> args0 }))
            .host(host.applyValue({ args0 -> args0 }))
            .port(port.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSourceParametersPostgresqlArgs].
 */
@PulumiTagMarker
public class DataSourceParametersPostgresqlArgsBuilder internal constructor() {
    private var database: Output<String>? = null

    private var host: Output<String>? = null

    private var port: Output<Int>? = null

    /**
     * @param value The database to which to connect.
     */
    @JvmName("ewksghofpephcpka")
    public suspend fun database(`value`: Output<String>) {
        this.database = value
    }

    /**
     * @param value The host to which to connect.
     */
    @JvmName("bainmdtwrkyvboah")
    public suspend fun host(`value`: Output<String>) {
        this.host = value
    }

    /**
     * @param value The port to which to connect.
     */
    @JvmName("jjuspmdrmataynfn")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value The database to which to connect.
     */
    @JvmName("xgdjapufvdfyeqnn")
    public suspend fun database(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.database = mapped
    }

    /**
     * @param value The host to which to connect.
     */
    @JvmName("kkmpqvasarwrtrhs")
    public suspend fun host(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.host = mapped
    }

    /**
     * @param value The port to which to connect.
     */
    @JvmName("kymtsripobqsexpd")
    public suspend fun port(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.port = mapped
    }

    internal fun build(): DataSourceParametersPostgresqlArgs = DataSourceParametersPostgresqlArgs(
        database = database ?: throw PulumiNullFieldException("database"),
        host = host ?: throw PulumiNullFieldException("host"),
        port = port ?: throw PulumiNullFieldException("port"),
    )
}
